@@ -33,7 +33,8 @@ L<Chj::IO::Pipe>, L<Chj::IO::File>
 
 =head1 NOTE
 
-This is alpha software! Read the package README.
+This is alpha software! Read the status section in the package README
+or on the L<website|http://functional-perl.org/>.
 
 =cut
 
